Machine learning helper function to reshape a matrix of
predicted probabilities to classes.
Usage
mlh_reshape(object)
Value
Returns a vector of type factor of the same length as rows in object,
representing the class with the highest probability for each observation in
object.
Arguments
object
A matrix with predicted probabilities for several classes.
Each row must sum up to 1.